aboutsummaryrefslogtreecommitdiff
path: root/Minecraft.World/ClientSideMerchant.cpp
diff options
context:
space:
mode:
authorvoid_17 <heroerror3@gmail.com>2026-03-02 15:58:20 +0700
committervoid_17 <heroerror3@gmail.com>2026-03-02 15:58:20 +0700
commit7074f35e4ba831e358117842b99ee35b87f85ae5 (patch)
tree7d440d23473196af3056bf2ff4c59d9e740a06f5 /Minecraft.World/ClientSideMerchant.cpp
parentd63f79325f85e014361eb8cf1e41eaebedb1ae71 (diff)
shared_ptr -> std::shared_ptr
This is one of the first commits in a plan to remove all `using namespace std;` lines in the entire codebase as it is considered anti-pattern today.
Diffstat (limited to 'Minecraft.World/ClientSideMerchant.cpp')
-rw-r--r--Minecraft.World/ClientSideMerchant.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/Minecraft.World/ClientSideMerchant.cpp b/Minecraft.World/ClientSideMerchant.cpp
index 5d021c22..9719cd48 100644
--- a/Minecraft.World/ClientSideMerchant.cpp
+++ b/Minecraft.World/ClientSideMerchant.cpp
@@ -3,10 +3,10 @@
#include "net.minecraft.world.inventory.h"
#include "ClientSideMerchant.h"
-ClientSideMerchant::ClientSideMerchant(shared_ptr<Player> source, int name)
+ClientSideMerchant::ClientSideMerchant(std::shared_ptr<Player> source, int name)
{
this->source = source;
// 4J Stu - Need to do this after creating as a shared_ptr
container = NULL; //new MerchantContainer(source, this);
currentOffers = NULL;
m_name = name;
@@ -28,17 +28,17 @@ Container *ClientSideMerchant::getContainer()
return container;
}
-shared_ptr<Player> ClientSideMerchant::getTradingPlayer()
+std::shared_ptr<Player> ClientSideMerchant::getTradingPlayer()
{
return source;
}
-void ClientSideMerchant::setTradingPlayer(shared_ptr<Player> player)
+void ClientSideMerchant::setTradingPlayer(std::shared_ptr<Player> player)
{
}
-MerchantRecipeList *ClientSideMerchant::getOffers(shared_ptr<Player> forPlayer)
+MerchantRecipeList *ClientSideMerchant::getOffers(std::shared_ptr<Player> forPlayer)
{
return currentOffers;
}
@@ -54,7 +54,7 @@ void ClientSideMerchant::notifyTrade(MerchantRecipe *activeRecipe)
activeRecipe->increaseUses();
}
-void ClientSideMerchant::notifyTradeUpdated(shared_ptr<ItemInstance> item)
+void ClientSideMerchant::notifyTradeUpdated(std::shared_ptr<ItemInstance> item)
{
}
@@ -3,10 +3,10 @@
{
this->source = source;
- // 4J Stu - Need to do this after creating as a shared_ptr
+ // 4J Stu - Need to do this after creating as a std::shared_ptr
container = NULL; //new MerchantContainer(source, this);
currentOffers = NULL;